<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.


/**
 * Completion Progress block Set Dates
 *
 * @package    block_individual_progress
 * @copyright  2018 BCLN
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

// Include required files.
require_once(dirname(__FILE__) . '/../../config.php');
require_once($CFG->dirroot.'/blocks/individual_progress/lib.php');
require_once(dirname(__FILE__) . '/form.php');

GLOBAL $USER;
// Gather form data.
$id       = required_param('instanceid', PARAM_INT);
$courseid = required_param('courseid', PARAM_INT);

// Determine course and context.
$course = $DB->get_record('course', array('id' => $courseid), '*', MUST_EXIST);
$context = CONTEXT_COURSE::instance($courseid);

// Get specific block config and context.
$block = $DB->get_record('block_instances', array('id' => $id), '*', MUST_EXIST);
$config = unserialize(base64_decode($block->configdata));
$blockcontext = CONTEXT_BLOCK::instance($id);

// Set up page parameters.
$PAGE->set_course($course);
$PAGE->requires->css('/blocks/individual_progress/styles.css');
$PAGE->set_url(
    '/blocks/individual_progress/setdates.php',
    array(
        'instanceid' => $id,
        'courseid'   => $courseid,
        'sesskey'    => sesskey(),
    )
);
$PAGE->set_context($context);
$title = get_string('setstart', 'block_individual_progress');
$PAGE->set_title($title);
$PAGE->set_heading($title);
$PAGE->navbar->add($title);
$PAGE->set_pagelayout('report');

// Check user is logged in and capable of accessing the Overview.
require_login($course, false);
confirm_sesskey();


// Check if activities/resources have been selected in config.
$activities = block_individual_progress_get_activities($courseid, $config);
if ($activities == null) {
    echo get_string('no_events_message', 'block_individual_progress');
    echo $OUTPUT->container_end();
    echo $OUTPUT->footer();
    die();
}
if (empty($activities)) {
    echo get_string('no_visible_events_message', 'block_individual_progress');
    echo $OUTPUT->container_end();
    echo $OUTPUT->footer();
    die();
}
// Creating the form.
$baseurl = new moodle_url('/blocks/individual_progress/setdates.php', array('instanceid' => $id, 'courseid' => $courseid));
$modinfo = get_fast_modinfo($course);

$mform = new report_editdates_form($baseurl, array('modinfo' => $modinfo,
        'course' => $course, 'instanceid' =>$id));

$returnurl = new moodle_url('/course/view.php', array('id' => $courseid));
if ($mform->is_cancelled()) {
    // Redirect to course view page if form is cancelled.
    redirect($returnurl);

} else if ($data = $mform->get_data()) {
    $uid = $USER->id;
    foreach ($data as $key => $value) {
        $lpos = strpos($key,'-');
        if ($lpos > '0') {
            $sl = strlen($key);
            $sl = $sl - $lpos - 1;
            $sl = $sl * -1;
            $val = substr($key,$sl);
            if ($DB->record_exists('individual_progress', array('course' => $courseid, 'userid' => $uid, 'coursemoduleid' => $val))) {
                $result = $DB->get_record('individual_progress', array('course' => $courseid, 'userid' => $uid, 'coursemoduleid' => $val));
                $recchanged = '0';
                if ($value != $result->deadline) {
                    $result->deadline = $value;
                    $recchanged = '1';
                } 
              
                if ($recchanged == '1') {
                    $DB->update_record('individual_progress',$result);
                }     
            } else {
               // create new record
               $data = new stdClass();
               $data->course = $courseid;
               $data->userid = $uid;
               $data->coursemoduleid = $val;
               $data->deadline = $value;
               $data->id = $DB->insert_record('individual_progress', $data);
            }
        }
    }
    redirect($returnurl);
}
// Start page output.
echo $OUTPUT->header();
echo $OUTPUT->heading($title, 2);

$mform->display();

echo $OUTPUT->footer();

